@@ -53,6 +53,15 @@ echo_multisite_groups.groups_required = [sitegroups.privileged.value]
 echo_multisite_groups.groups_forbidden = [sitegroups.forbidden.value]
 
 
+def process_request(request, body):
+    return {'body': body, 'headers': request.headers}
+
+
+def process_raw_request(request):
+    return {'raw_body': request.stream.read().decode(), 'headers': request.headers}
+process_raw_request.not_found_on_none = True
+
+
 def setup_routes(factory):
 
     factory.get('/echo/{word}')(echo)
@@ -71,5 +80,8 @@ def setup_routes(factory):
     factory.get('/sites/{site_id}/echo-groups')(echo_multisite_groups)
     factory.get('/sites/{site_id}/snakes/{name}')(get_secure_snake)
 
+    factory.post('/request-and-body')(process_request)
+    factory.post('/request-raw-body', parse_body=False)(process_raw_request)
+
     # ar_handlers = (None, arlib.create, None, arlib.get, arlib.update, None)
     # factory.map_resource('/resttest/', handlers=ar_handlers)
